import logging
import sys

from tenzir.utils.config import create as create_config, Config


def configure(config: Config, logger: logging.Logger):
    fmt = "%(asctime)s %(name)s %(levelname)-7s %(message)s"
    plain_formatter = logging.Formatter(fmt)
    if config.get("file-verbosity") != "quiet":
        fh = logging.FileHandler(config.get("log-file"))
        fh_level = logging.getLevelName(config.get("file-verbosity").upper())
        logger.setLevel(fh_level)
        fh.setLevel(fh_level)
        fh.setFormatter(plain_formatter)
        logger.addHandler(fh)
    if config.get("console-verbosity") != "quiet":
        ch = logging.StreamHandler()
        ch_level = logging.getLevelName(config.get("console-verbosity").upper())
        ch.setLevel(ch_level)
        if logger.level > ch_level or logger.level == 0:
            logger.setLevel(ch_level)
        ch.setFormatter(plain_formatter)
        logger.addHandler(ch)

    class ShutdownHandler(logging.Handler):
        """Exit application with CRITICAL logs"""

        def emit(self, _):
            logging.shutdown()
            sys.exit(1)

    sh = ShutdownHandler(level=50)
    sh.setFormatter(plain_formatter)
    logger.addHandler(sh)


def get(name=None):
    """Get a logger instance while ensuring that the Tenzir logger namespace
    (loggers with name "tenzir or "tenzir.*") is properly configured"""
    # The logger "tenzir" is the root of the namespace. All loggers names tenzir.*
    # will inherit its settings
    tenzir_logger = logging.getLogger("tenzir")
    # Setting "propagate" to false disables inheritance from the root logger
    tenzir_logger.propagate = False
    # If the logger has no handlers, it means it hasn't been configured yet.
    if not tenzir_logger.hasHandlers():
        configure(create_config(), tenzir_logger)
    return logging.getLogger(name)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tenzir', 'tenzir.apps', 'tenzir.tenzir', 'tenzir.tools', 'tenzir.utils']

package_data = \
{'': ['*']}

install_requires = \
['dynaconf>=3.2,<4.0', 'pyarrow>=11,<15']

extras_require = \
{'module': ['numpy>=1.24,<2.0'],
 'operator': ['python-box>=7.0,<8.0', 'pandas>=2.1.3,<3.0.0'],
 'thehive': ['aiohttp>=3.8,<4.0']}

entry_points = \
{'console_scripts': ['app-thehive-count-alerts = '
                     'tenzir.apps.thehive:count_alerts',
                     'app-thehive-run = tenzir.apps.thehive:run']}

setup_kwargs = {
    'name': 'tenzir',
    'version': '4.6.2',
    'description': 'A security telemetry engine for detection and response',
    'long_description': '# Tenzir Python\n\nThe Python package of Tenzir provides a flexible control plane to integrate Tenzir\nwith other security tools.\n\n> **Note**\n> The Python effort is still highly experimental and subject to rapid change.\n> Please do not consider it for production use.\n\n## Usage\n\nTo get started, clone the Tenzir repository and install the Python package via\n[Poetry](https://python-poetry.org/docs/):\n\n```bash\ngit clone https://github.com/tenzir/tenzir.git\ncd tenzir/python\npoetry install -E module\n```\n\n## Development\n\nWe recommend that you work with an editable installation, which is the default\nfor `poetry install`.\n\n### Unit Tests\n\nRun the unit tests via pytest:\n\n```bash\npoetry run pytest\n```\n\n### Integration Tests\n\nRun the integrations tests via Docker Compose and pytest:\n\n```bash\n./docker-poetry-run.sh pytest -v\n```\n\n## Packaging\n\nThe following instructions concern maintainers who want to publish the Python\npackage to PyPI.\n\n> **Note**\n> Our releasing scripts and CI run these steps automatically. You do not need to\n> intervene anywhere. The instructions below merely document the steps taken.\n\n### Bump the version\n\nPrior to releasing a new version, bump the version, e.g.:\n\n```bash\npoetry version 2.3.1\n```\n\nThis updates the `pyproject.toml` file.\n\n### Publish to Test PyPI\n\n1. Add a Test PyPi repository:\n\n   ```bash\n   poetry config repositories.test-pypi https://test.pypi.org/legacy/\n   ```\n\n2. Get the token from <https://test.pypi.org/manage/account/token/>.\n\n3. Store the token:\n\n  ```bash\n  poetry config pypi-token.test-pypi pypi-XXXXXXXX\n  ```\n\n4. Publish:\n  \n   ```bash\n   poetry publish --build -r test-pypi\n   ```\n\n### Publish to PyPI\n\n1. Get the token from <https://pypi.org/manage/account/token/>.\n\n2. Store the token:\n\n  ```bash\n  poetry config pypi-token.pypi pypi-XXXXXXXX\n  ```\n\n3. Publish\n\n   ```bash\n   poetry publish --build\n   ```\n',
    'author': 'Tenzir',
    'author_email': 'engineering@tenzir.com',
    'maintainer': 'Tenzir',
    'maintainer_email': 'engineering@tenzir.com',
    'url': 'https://tenzir.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
